import { NextFunction, Request, Response } from 'express';
interface QueryString {
    use: boolean;
    key: string;
    value: string;
    locals: object | string;
}
interface Options {
    querystring: Partial<QueryString>;
    additionalBots: Partial<string[]>;
}
/**
 * Express middleware
 * @param options Partial<Options>
 * @returns {Function}
 * @example
 *
 * app.use(require('express-bot')({
 *   querystring: { // dicision using querystring  https://localhost?bot=1 -> hit!!
 *     use: true,
 *     key: 'bot',
 *     value: '1',
 *   },
 *   additionalBots: [ // list of UA strings to be added to pre-defined BOTS.
 *     'MinorBot'
 *   ]
 * }));
 */
declare const expressBot: (options?: Partial<Options>) => (req: Request, res: Response, next: NextFunction) => void;
export default expressBot;
//# sourceMappingURL=index.d.ts.map